# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: testpb/test_schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from cosmos.orm.v1 import orm_pb2 as cosmos_dot_orm_dot_v1_dot_orm__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18testpb/test_schema.proto\x12\x06testpb\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17\x63osmos/orm/v1/orm.proto\"\xc0\x04\n\x0c\x45xampleTable\x12\x0b\n\x03u32\x18\x01 \x01(\r\x12\x0b\n\x03u64\x18\x02 \x01(\x04\x12\x0b\n\x03str\x18\x03 \x01(\t\x12\n\n\x02\x62z\x18\x04 \x01(\x0c\x12&\n\x02ts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x03\x64ur\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0b\n\x03i32\x18\x07 \x01(\x05\x12\x0b\n\x03s32\x18\x08 \x01(\x11\x12\x0c\n\x04sf32\x18\t \x01(\x0f\x12\x0b\n\x03i64\x18\n \x01(\x03\x12\x0b\n\x03s64\x18\x0b \x01(\x12\x12\x0c\n\x04sf64\x18\x0c \x01(\x10\x12\x0b\n\x03\x66\x33\x32\x18\r \x01(\x07\x12\x0b\n\x03\x66\x36\x34\x18\x0e \x01(\x06\x12\t\n\x01\x62\x18\x0f \x01(\x08\x12\x17\n\x01\x65\x18\x10 \x01(\x0e\x32\x0c.testpb.Enum\x12\x10\n\x08repeated\x18\x11 \x03(\r\x12*\n\x03map\x18\x12 \x03(\x0b\x32\x1d.testpb.ExampleTable.MapEntry\x12\x30\n\x03msg\x18\x13 \x01(\x0b\x32#.testpb.ExampleTable.ExampleMessage\x12\x0f\n\x05oneof\x18\x14 \x01(\rH\x00\x1a*\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x1a*\n\x0e\x45xampleMessage\x12\x0b\n\x03\x66oo\x18\x01 \x01(\t\x12\x0b\n\x03\x62\x61r\x18\x02 \x01(\x05:?\xf2\x9e\xd3\x8e\x03\x39\n\r\n\x0bu32,i64,str\x12\r\n\x07u64,str\x10\x01\x18\x01\x12\x0b\n\x07str,u32\x10\x02\x12\n\n\x06\x62z,str\x10\x03\x18\x01\x42\x05\n\x03sum\"X\n\x19\x45xampleAutoIncrementTable\x12\n\n\x02id\x18\x01 \x01(\x04\x12\t\n\x01x\x18\x02 \x01(\t\x12\t\n\x01y\x18\x03 \x01(\x05:\x19\xf2\x9e\xd3\x8e\x03\x13\n\x06\n\x02id\x10\x01\x12\x07\n\x01x\x10\x01\x18\x01\x18\x03\"6\n\x10\x45xampleSingleton\x12\x0b\n\x03\x66oo\x18\x01 \x01(\t\x12\x0b\n\x03\x62\x61r\x18\x02 \x01(\x05:\x08\xfa\x9e\xd3\x8e\x03\x02\x08\x02\"n\n\x10\x45xampleTimestamp\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12&\n\x02ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x18\xf2\x9e\xd3\x8e\x03\x12\n\x06\n\x02id\x10\x01\x12\x06\n\x02ts\x10\x01\x18\x04\"a\n\rSimpleExample\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06unique\x18\x02 \x01(\t\x12\x12\n\nnot_unique\x18\x03 \x01(\t:\x1e\xf2\x9e\xd3\x8e\x03\x18\n\x06\n\x04name\x12\x0c\n\x06unique\x10\x01\x18\x01\x18\x05\"F\n\x17\x45xampleAutoIncFieldName\x12\x0b\n\x03\x66oo\x18\x01 \x01(\x04\x12\x0b\n\x03\x62\x61r\x18\x02 \x01(\x04:\x11\xf2\x9e\xd3\x8e\x03\x0b\n\x07\n\x03\x66oo\x10\x01\x18\x06*d\n\x04\x45num\x12\x14\n\x10\x45NUM_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x45NUM_ONE\x10\x01\x12\x0c\n\x08\x45NUM_TWO\x10\x02\x12\r\n\tENUM_FIVE\x10\x05\x12\x1b\n\x0e\x45NUM_NEG_THREE\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'testpb.test_schema_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXAMPLETABLE_MAPENTRY._options = None
  _EXAMPLETABLE_MAPENTRY._serialized_options = b'8\001'
  _EXAMPLETABLE._options = None
  _EXAMPLETABLE._serialized_options = b'\362\236\323\216\0039\n\r\n\013u32,i64,str\022\r\n\007u64,str\020\001\030\001\022\013\n\007str,u32\020\002\022\n\n\006bz,str\020\003\030\001'
  _EXAMPLEAUTOINCREMENTTABLE._options = None
  _EXAMPLEAUTOINCREMENTTABLE._serialized_options = b'\362\236\323\216\003\023\n\006\n\002id\020\001\022\007\n\001x\020\001\030\001\030\003'
  _EXAMPLESINGLETON._options = None
  _EXAMPLESINGLETON._serialized_options = b'\372\236\323\216\003\002\010\002'
  _EXAMPLETIMESTAMP._options = None
  _EXAMPLETIMESTAMP._serialized_options = b'\362\236\323\216\003\022\n\006\n\002id\020\001\022\006\n\002ts\020\001\030\004'
  _SIMPLEEXAMPLE._options = None
  _SIMPLEEXAMPLE._serialized_options = b'\362\236\323\216\003\030\n\006\n\004name\022\014\n\006unique\020\001\030\001\030\005'
  _EXAMPLEAUTOINCFIELDNAME._options = None
  _EXAMPLEAUTOINCFIELDNAME._serialized_options = b'\362\236\323\216\003\013\n\007\n\003foo\020\001\030\006'
  _globals['_ENUM']._serialized_start=1134
  _globals['_ENUM']._serialized_end=1234
  _globals['_EXAMPLETABLE']._serialized_start=127
  _globals['_EXAMPLETABLE']._serialized_end=703
  _globals['_EXAMPLETABLE_MAPENTRY']._serialized_start=545
  _globals['_EXAMPLETABLE_MAPENTRY']._serialized_end=587
  _globals['_EXAMPLETABLE_EXAMPLEMESSAGE']._serialized_start=589
  _globals['_EXAMPLETABLE_EXAMPLEMESSAGE']._serialized_end=631
  _globals['_EXAMPLEAUTOINCREMENTTABLE']._serialized_start=705
  _globals['_EXAMPLEAUTOINCREMENTTABLE']._serialized_end=793
  _globals['_EXAMPLESINGLETON']._serialized_start=795
  _globals['_EXAMPLESINGLETON']._serialized_end=849
  _globals['_EXAMPLETIMESTAMP']._serialized_start=851
  _globals['_EXAMPLETIMESTAMP']._serialized_end=961
  _globals['_SIMPLEEXAMPLE']._serialized_start=963
  _globals['_SIMPLEEXAMPLE']._serialized_end=1060
  _globals['_EXAMPLEAUTOINCFIELDNAME']._serialized_start=1062
  _globals['_EXAMPLEAUTOINCFIELDNAME']._serialized_end=1132
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v2/packet.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ibc/applications/transfer/v2/packet.proto\x12\x1cibc.applications.transfer.v2\"h\n\x17\x46ungibleTokenPacketData\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\x12\x0e\n\x06sender\x18\x03 \x01(\t\x12\x10\n\x08receiver\x18\x04 \x01(\t\x12\x0c\n\x04memo\x18\x05 \x01(\tB9Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v2.packet_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/types'
  _globals['_FUNGIBLETOKENPACKETDATA']._serialized_start=75
  _globals['_FUNGIBLETOKENPACKETDATA']._serialized_end=179
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_oracle_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#exchange/injective_oracle_rpc.proto\x12\x14injective_oracle_rpc\"\x13\n\x11OracleListRequest\"C\n\x12OracleListResponse\x12-\n\x07oracles\x18\x01 \x03(\x0b\x32\x1c.injective_oracle_rpc.Oracle\"g\n\x06Oracle\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x13\n\x0b\x62\x61se_symbol\x18\x02 \x01(\t\x12\x14\n\x0cquote_symbol\x18\x03 \x01(\t\x12\x13\n\x0boracle_type\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\"k\n\x0cPriceRequest\x12\x13\n\x0b\x62\x61se_symbol\x18\x01 \x01(\t\x12\x14\n\x0cquote_symbol\x18\x02 \x01(\t\x12\x13\n\x0boracle_type\x18\x03 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x04 \x01(\r\"\x1e\n\rPriceResponse\x12\r\n\x05price\x18\x01 \x01(\t\"U\n\x13StreamPricesRequest\x12\x13\n\x0b\x62\x61se_symbol\x18\x01 \x01(\t\x12\x14\n\x0cquote_symbol\x18\x02 \x01(\t\x12\x13\n\x0boracle_type\x18\x03 \x01(\t\"8\n\x14StreamPricesResponse\x12\r\n\x05price\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x12\"2\n\x1cStreamPricesByMarketsRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"T\n\x1dStreamPricesByMarketsResponse\x12\r\n\x05price\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x12\x12\x11\n\tmarket_id\x18\x03 \x01(\t2\xb5\x03\n\x12InjectiveOracleRPC\x12_\n\nOracleList\x12\'.injective_oracle_rpc.OracleListRequest\x1a(.injective_oracle_rpc.OracleListResponse\x12P\n\x05Price\x12\".injective_oracle_rpc.PriceRequest\x1a#.injective_oracle_rpc.PriceResponse\x12g\n\x0cStreamPrices\x12).injective_oracle_rpc.StreamPricesRequest\x1a*.injective_oracle_rpc.StreamPricesResponse0\x01\x12\x82\x01\n\x15StreamPricesByMarkets\x12\x32.injective_oracle_rpc.StreamPricesByMarketsRequest\x1a\x33.injective_oracle_rpc.StreamPricesByMarketsResponse0\x01\x42\x19Z\x17/injective_oracle_rpcpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_oracle_rpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\027/injective_oracle_rpcpb'
  _globals['_ORACLELISTREQUEST']._serialized_start=61
  _globals['_ORACLELISTREQUEST']._serialized_end=80
  _globals['_ORACLELISTRESPONSE']._serialized_start=82
  _globals['_ORACLELISTRESPONSE']._serialized_end=149
  _globals['_ORACLE']._serialized_start=151
  _globals['_ORACLE']._serialized_end=254
  _globals['_PRICEREQUEST']._serialized_start=256
  _globals['_PRICEREQUEST']._serialized_end=363
  _globals['_PRICERESPONSE']._serialized_start=365
  _globals['_PRICERESPONSE']._serialized_end=395
  _globals['_STREAMPRICESREQUEST']._serialized_start=397
  _globals['_STREAMPRICESREQUEST']._serialized_end=482
  _globals['_STREAMPRICESRESPONSE']._serialized_start=484
  _globals['_STREAMPRICESRESPONSE']._serialized_end=540
  _globals['_STREAMPRICESBYMARKETSREQUEST']._serialized_start=542
  _globals['_STREAMPRICESBYMARKETSREQUEST']._serialized_end=592
  _globals['_STREAMPRICESBYMARKETSRESPONSE']._serialized_start=594
  _globals['_STREAMPRICESBYMARKETSRESPONSE']._serialized_end=678
  _globals['_INJECTIVEORACLERPC']._serialized_start=681
  _globals['_INJECTIVEORACLERPC']._serialized_end=1118
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_accounts_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_accounts_rpc.proto\x12\x16injective_accounts_rpc\"+\n\x10PortfolioRequest\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\"P\n\x11PortfolioResponse\x12;\n\tportfolio\x18\x01 \x01(\x0b\x32(.injective_accounts_rpc.AccountPortfolio\"\xb8\x01\n\x10\x41\x63\x63ountPortfolio\x12\x17\n\x0fportfolio_value\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\x12\x16\n\x0elocked_balance\x18\x03 \x01(\t\x12\x16\n\x0eunrealized_pnl\x18\x04 \x01(\t\x12@\n\x0bsubaccounts\x18\x05 \x03(\x0b\x32+.injective_accounts_rpc.SubaccountPortfolio\"w\n\x13SubaccountPortfolio\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\x12\x16\n\x0elocked_balance\x18\x03 \x01(\t\x12\x16\n\x0eunrealized_pnl\x18\x04 \x01(\t\"P\n\x12OrderStatesRequest\x12\x19\n\x11spot_order_hashes\x18\x01 \x03(\t\x12\x1f\n\x17\x64\x65rivative_order_hashes\x18\x02 \x03(\t\"\xa5\x01\n\x13OrderStatesResponse\x12\x43\n\x11spot_order_states\x18\x01 \x03(\x0b\x32(.injective_accounts_rpc.OrderStateRecord\x12I\n\x17\x64\x65rivative_order_states\x18\x02 \x03(\x0b\x32(.injective_accounts_rpc.OrderStateRecord\"\xe4\x01\n\x10OrderStateRecord\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x12\n\norder_type\x18\x04 \x01(\t\x12\x12\n\norder_side\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x17\n\x0fquantity_filled\x18\x07 \x01(\t\x12\x1a\n\x12quantity_remaining\x18\x08 \x01(\t\x12\x12\n\ncreated_at\x18\t \x01(\x12\x12\x12\n\nupdated_at\x18\n \x01(\x12\"1\n\x16SubaccountsListRequest\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\".\n\x17SubaccountsListResponse\x12\x13\n\x0bsubaccounts\x18\x01 \x03(\t\"F\n\x1dSubaccountBalancesListRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65noms\x18\x02 \x03(\t\"]\n\x1eSubaccountBalancesListResponse\x12;\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32).injective_accounts_rpc.SubaccountBalance\"\x8e\x01\n\x11SubaccountBalance\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\x12:\n\x07\x64\x65posit\x18\x04 \x01(\x0b\x32).injective_accounts_rpc.SubaccountDeposit\"E\n\x11SubaccountDeposit\x12\x15\n\rtotal_balance\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\"H\n SubaccountBalanceEndpointRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"_\n!SubaccountBalanceEndpointResponse\x12:\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32).injective_accounts_rpc.SubaccountBalance\"G\n\x1eStreamSubaccountBalanceRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65noms\x18\x02 \x03(\t\"p\n\x1fStreamSubaccountBalanceResponse\x12:\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32).injective_accounts_rpc.SubaccountBalance\x12\x11\n\ttimestamp\x18\x02 \x01(\x12\"\x87\x01\n\x18SubaccountHistoryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x16\n\x0etransfer_types\x18\x03 \x03(\t\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x11\x12\x10\n\x08\x65nd_time\x18\x06 \x01(\x12\"\x91\x01\n\x19SubaccountHistoryResponse\x12\x44\n\ttransfers\x18\x01 \x03(\x0b\x32\x31.injective_accounts_rpc.SubaccountBalanceTransfer\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x1e.injective_accounts_rpc.Paging\"\xeb\x01\n\x19SubaccountBalanceTransfer\x12\x15\n\rtransfer_type\x18\x01 \x01(\t\x12\x19\n\x11src_subaccount_id\x18\x02 \x01(\t\x12\x1b\n\x13src_account_address\x18\x03 \x01(\t\x12\x19\n\x11\x64st_subaccount_id\x18\x04 \x01(\t\x12\x1b\n\x13\x64st_account_address\x18\x05 \x01(\t\x12\x32\n\x06\x61mount\x18\x06 \x01(\x0b\x32\".injective_accounts_rpc.CosmosCoin\x12\x13\n\x0b\x65xecuted_at\x18\x07 \x01(\x12\"+\n\nCosmosCoin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\\\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\x12\x1b\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12\x12\x0c\n\x04next\x18\x05 \x03(\t\"b\n\x1dSubaccountOrderSummaryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x17\n\x0forder_direction\x18\x03 \x01(\t\"\\\n\x1eSubaccountOrderSummaryResponse\x12\x19\n\x11spot_orders_total\x18\x01 \x01(\x12\x12\x1f\n\x17\x64\x65rivative_orders_total\x18\x02 \x01(\x12\"8\n\x0eRewardsRequest\x12\r\n\x05\x65poch\x18\x01 \x01(\x12\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\t\"B\n\x0fRewardsResponse\x12/\n\x07rewards\x18\x01 \x03(\x0b\x32\x1e.injective_accounts_rpc.Reward\"h\n\x06Reward\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12-\n\x07rewards\x18\x02 \x03(\x0b\x32\x1c.injective_accounts_rpc.Coin\x12\x16\n\x0e\x64istributed_at\x18\x03 \x01(\x12\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t2\xe0\x08\n\x14InjectiveAccountsRPC\x12`\n\tPortfolio\x12(.injective_accounts_rpc.PortfolioRequest\x1a).injective_accounts_rpc.PortfolioResponse\x12\x66\n\x0bOrderStates\x12*.injective_accounts_rpc.OrderStatesRequest\x1a+.injective_accounts_rpc.OrderStatesResponse\x12r\n\x0fSubaccountsList\x12..injective_accounts_rpc.SubaccountsListRequest\x1a/.injective_accounts_rpc.SubaccountsListResponse\x12\x87\x01\n\x16SubaccountBalancesList\x12\x35.injective_accounts_rpc.SubaccountBalancesListRequest\x1a\x36.injective_accounts_rpc.SubaccountBalancesListResponse\x12\x90\x01\n\x19SubaccountBalanceEndpoint\x12\x38.injective_accounts_rpc.SubaccountBalanceEndpointRequest\x1a\x39.injective_accounts_rpc.SubaccountBalanceEndpointResponse\x12\x8c\x01\n\x17StreamSubaccountBalance\x12\x36.injective_accounts_rpc.StreamSubaccountBalanceRequest\x1a\x37.injective_accounts_rpc.StreamSubaccountBalanceResponse0\x01\x12x\n\x11SubaccountHistory\x12\x30.injective_accounts_rpc.SubaccountHistoryRequest\x1a\x31.injective_accounts_rpc.SubaccountHistoryResponse\x12\x87\x01\n\x16SubaccountOrderSummary\x12\x35.injective_accounts_rpc.SubaccountOrderSummaryRequest\x1a\x36.injective_accounts_rpc.SubaccountOrderSummaryResponse\x12Z\n\x07Rewards\x12&.injective_accounts_rpc.RewardsRequest\x1a\'.injective_accounts_rpc.RewardsResponseB\x1bZ\x19/injective_accounts_rpcpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_accounts_rpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\031/injective_accounts_rpcpb'
  _globals['_PORTFOLIOREQUEST']._serialized_start=65
  _globals['_PORTFOLIOREQUEST']._serialized_end=108
  _globals['_PORTFOLIORESPONSE']._serialized_start=110
  _globals['_PORTFOLIORESPONSE']._serialized_end=190
  _globals['_ACCOUNTPORTFOLIO']._serialized_start=193
  _globals['_ACCOUNTPORTFOLIO']._serialized_end=377
  _globals['_SUBACCOUNTPORTFOLIO']._serialized_start=379
  _globals['_SUBACCOUNTPORTFOLIO']._serialized_end=498
  _globals['_ORDERSTATESREQUEST']._serialized_start=500
  _globals['_ORDERSTATESREQUEST']._serialized_end=580
  _globals['_ORDERSTATESRESPONSE']._serialized_start=583
  _globals['_ORDERSTATESRESPONSE']._serialized_end=748
  _globals['_ORDERSTATERECORD']._serialized_start=751
  _globals['_ORDERSTATERECORD']._serialized_end=979
  _globals['_SUBACCOUNTSLISTREQUEST']._serialized_start=981
  _globals['_SUBACCOUNTSLISTREQUEST']._serialized_end=1030
  _globals['_SUBACCOUNTSLISTRESPONSE']._serialized_start=1032
  _globals['_SUBACCOUNTSLISTRESPONSE']._serialized_end=1078
  _globals['_SUBACCOUNTBALANCESLISTREQUEST']._serialized_start=1080
  _globals['_SUBACCOUNTBALANCESLISTREQUEST']._serialized_end=1150
  _globals['_SUBACCOUNTBALANCESLISTRESPONSE']._serialized_start=1152
  _globals['_SUBACCOUNTBALANCESLISTRESPONSE']._serialized_end=1245
  _globals['_SUBACCOUNTBALANCE']._serialized_start=1248
  _globals['_SUBACCOUNTBALANCE']._serialized_end=1390
  _globals['_SUBACCOUNTDEPOSIT']._serialized_start=1392
  _globals['_SUBACCOUNTDEPOSIT']._serialized_end=1461
  _globals['_SUBACCOUNTBALANCEENDPOINTREQUEST']._serialized_start=1463
  _globals['_SUBACCOUNTBALANCEENDPOINTREQUEST']._serialized_end=1535
  _globals['_SUBACCOUNTBALANCEENDPOINTRESPONSE']._serialized_start=1537
  _globals['_SUBACCOUNTBALANCEENDPOINTRESPONSE']._serialized_end=1632
  _globals['_STREAMSUBACCOUNTBALANCEREQUEST']._serialized_start=1634
  _globals['_STREAMSUBACCOUNTBALANCEREQUEST']._serialized_end=1705
  _globals['_STREAMSUBACCOUNTBALANCERESPONSE']._serialized_start=1707
  _globals['_STREAMSUBACCOUNTBALANCERESPONSE']._serialized_end=1819
  _globals['_SUBACCOUNTHISTORYREQUEST']._serialized_start=1822
  _globals['_SUBACCOUNTHISTORYREQUEST']._serialized_end=1957
  _globals['_SUBACCOUNTHISTORYRESPONSE']._serialized_start=1960
  _globals['_SUBACCOUNTHISTORYRESPONSE']._serialized_end=2105
  _globals['_SUBACCOUNTBALANCETRANSFER']._serialized_start=2108
  _globals['_SUBACCOUNTBALANCETRANSFER']._serialized_end=2343
  _globals['_COSMOSCOIN']._serialized_start=2345
  _globals['_COSMOSCOIN']._serialized_end=2388
  _globals['_PAGING']._serialized_start=2390
  _globals['_PAGING']._serialized_end=2482
  _globals['_SUBACCOUNTORDERSUMMARYREQUEST']._serialized_start=2484
  _globals['_SUBACCOUNTORDERSUMMARYREQUEST']._serialized_end=2582
  _globals['_SUBACCOUNTORDERSUMMARYRESPONSE']._serialized_start=2584
  _globals['_SUBACCOUNTORDERSUMMARYRESPONSE']._serialized_end=2676
  _globals['_REWARDSREQUEST']._serialized_start=2678
  _globals['_REWARDSREQUEST']._serialized_end=2734
  _globals['_REWARDSRESPONSE']._serialized_start=2736
  _globals['_REWARDSRESPONSE']._serialized_end=2802
  _globals['_REWARD']._serialized_start=2804
  _globals['_REWARD']._serialized_end=2908
  _globals['_COIN']._serialized_start=2910
  _globals['_COIN']._serialized_end=2947
  _globals['_INJECTIVEACCOUNTSRPC']._serialized_start=2950
  _globals['_INJECTIVEACCOUNTSRPC']._serialized_end=4070
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmwasm/wasm/v1/authz.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19google/protobuf/any.proto\x1a\x11\x61mino/amino.proto\"\xac\x01\n\x1e\x43ontractExecutionAuthorization\x12:\n\x06grants\x18\x01 \x03(\x0b\x32\x1f.cosmwasm.wasm.v1.ContractGrantB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:N\xca\xb4-\"cosmos.authz.v1beta1.Authorization\x8a\xe7\xb0*#wasm/ContractExecutionAuthorization\"\xac\x01\n\x1e\x43ontractMigrationAuthorization\x12:\n\x06grants\x18\x01 \x03(\x0b\x32\x1f.cosmwasm.wasm.v1.ContractGrantB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:N\xca\xb4-\"cosmos.authz.v1beta1.Authorization\x8a\xe7\xb0*#wasm/ContractMigrationAuthorization\"\xc1\x01\n\rContractGrant\x12\x10\n\x08\x63ontract\x18\x01 \x01(\t\x12M\n\x05limit\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB(\xca\xb4-$cosmwasm.wasm.v1.ContractAuthzLimitX\x12O\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB)\xca\xb4-%cosmwasm.wasm.v1.ContractAuthzFilterX\"c\n\rMaxCallsLimit\x12\x11\n\tremaining\x18\x01 \x01(\x04:?\xca\xb4-$cosmwasm.wasm.v1.ContractAuthzLimitX\x8a\xe7\xb0*\x12wasm/MaxCallsLimit\"\xb3\x01\n\rMaxFundsLimit\x12\x61\n\x07\x61mounts\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01:?\xca\xb4-$cosmwasm.wasm.v1.ContractAuthzLimitX\x8a\xe7\xb0*\x12wasm/MaxFundsLimit\"\xcc\x01\n\rCombinedLimit\x12\x17\n\x0f\x63\x61lls_remaining\x18\x01 \x01(\x04\x12\x61\n\x07\x61mounts\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01:?\xca\xb4-$cosmwasm.wasm.v1.ContractAuthzLimitX\x8a\xe7\xb0*\x12wasm/CombinedLimit\"c\n\x16\x41llowAllMessagesFilter:I\xca\xb4-%cosmwasm.wasm.v1.ContractAuthzFilterX\x8a\xe7\xb0*\x1bwasm/AllowAllMessagesFilter\"w\n\x19\x41\x63\x63\x65ptedMessageKeysFilter\x12\x0c\n\x04keys\x18\x01 \x03(\t:L\xca\xb4-%cosmwasm.wasm.v1.ContractAuthzFilterX\x8a\xe7\xb0*\x1ewasm/AcceptedMessageKeysFilter\"\x8d\x01\n\x16\x41\x63\x63\x65ptedMessagesFilter\x12(\n\x08messages\x18\x01 \x03(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage:I\xca\xb4-%cosmwasm.wasm.v1.ContractAuthzFilterX\x8a\xe7\xb0*\x1bwasm/AcceptedMessagesFilterB,Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.authz_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000'
  _CONTRACTEXECUTIONAUTHORIZATION.fields_by_name['grants']._options = None
  _CONTRACTEXECUTIONAUTHORIZATION.fields_by_name['grants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _CONTRACTEXECUTIONAUTHORIZATION._options = None
  _CONTRACTEXECUTIONAUTHORIZATION._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization\212\347\260*#wasm/ContractExecutionAuthorization'
  _CONTRACTMIGRATIONAUTHORIZATION.fields_by_name['grants']._options = None
  _CONTRACTMIGRATIONAUTHORIZATION.fields_by_name['grants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _CONTRACTMIGRATIONAUTHORIZATION._options = None
  _CONTRACTMIGRATIONAUTHORIZATION._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization\212\347\260*#wasm/ContractMigrationAuthorization'
  _CONTRACTGRANT.fields_by_name['limit']._options = None
  _CONTRACTGRANT.fields_by_name['limit']._serialized_options = b'\312\264-$cosmwasm.wasm.v1.ContractAuthzLimitX'
  _CONTRACTGRANT.fields_by_name['filter']._options = None
  _CONTRACTGRANT.fields_by_name['filter']._serialized_options = b'\312\264-%cosmwasm.wasm.v1.ContractAuthzFilterX'
  _MAXCALLSLIMIT._options = None
  _MAXCALLSLIMIT._serialized_options = b'\312\264-$cosmwasm.wasm.v1.ContractAuthzLimitX\212\347\260*\022wasm/MaxCallsLimit'
  _MAXFUNDSLIMIT.fields_by_name['amounts']._options = None
  _MAXFUNDSLIMIT.fields_by_name['amounts']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _MAXFUNDSLIMIT._options = None
  _MAXFUNDSLIMIT._serialized_options = b'\312\264-$cosmwasm.wasm.v1.ContractAuthzLimitX\212\347\260*\022wasm/MaxFundsLimit'
  _COMBINEDLIMIT.fields_by_name['amounts']._options = None
  _COMBINEDLIMIT.fields_by_name['amounts']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _COMBINEDLIMIT._options = None
  _COMBINEDLIMIT._serialized_options = b'\312\264-$cosmwasm.wasm.v1.ContractAuthzLimitX\212\347\260*\022wasm/CombinedLimit'
  _ALLOWALLMESSAGESFILTER._options = None
  _ALLOWALLMESSAGESFILTER._serialized_options = b'\312\264-%cosmwasm.wasm.v1.ContractAuthzFilterX\212\347\260*\033wasm/AllowAllMessagesFilter'
  _ACCEPTEDMESSAGEKEYSFILTER._options = None
  _ACCEPTEDMESSAGEKEYSFILTER._serialized_options = b'\312\264-%cosmwasm.wasm.v1.ContractAuthzFilterX\212\347\260*\036wasm/AcceptedMessageKeysFilter'
  _ACCEPTEDMESSAGESFILTER.fields_by_name['messages']._options = None
  _ACCEPTEDMESSAGESFILTER.fields_by_name['messages']._serialized_options = b'\372\336\037\022RawContractMessage'
  _ACCEPTEDMESSAGESFILTER._options = None
  _ACCEPTEDMESSAGESFILTER._serialized_options = b'\312\264-%cosmwasm.wasm.v1.ContractAuthzFilterX\212\347\260*\033wasm/AcceptedMessagesFilter'
  _globals['_CONTRACTEXECUTIONAUTHORIZATION']._serialized_start=178
  _globals['_CONTRACTEXECUTIONAUTHORIZATION']._serialized_end=350
  _globals['_CONTRACTMIGRATIONAUTHORIZATION']._serialized_start=353
  _globals['_CONTRACTMIGRATIONAUTHORIZATION']._serialized_end=525
  _globals['_CONTRACTGRANT']._serialized_start=528
  _globals['_CONTRACTGRANT']._serialized_end=721
  _globals['_MAXCALLSLIMIT']._serialized_start=723
  _globals['_MAXCALLSLIMIT']._serialized_end=822
  _globals['_MAXFUNDSLIMIT']._serialized_start=825
  _globals['_MAXFUNDSLIMIT']._serialized_end=1004
  _globals['_COMBINEDLIMIT']._serialized_start=1007
  _globals['_COMBINEDLIMIT']._serialized_end=1211
  _globals['_ALLOWALLMESSAGESFILTER']._serialized_start=1213
  _globals['_ALLOWALLMESSAGESFILTER']._serialized_end=1312
  _globals['_ACCEPTEDMESSAGEKEYSFILTER']._serialized_start=1314
  _globals['_ACCEPTEDMESSAGEKEYSFILTER']._serialized_end=1433
  _globals['_ACCEPTEDMESSAGESFILTER']._serialized_start=1436
  _globals['_ACCEPTEDMESSAGESFILTER']._serialized_end=1577
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/module/v1/module.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/gov/module/v1/module.proto\x12\x14\x63osmos.gov.module.v1\x1a cosmos/app/v1alpha1/module.proto\"a\n\x06Module\x12\x18\n\x10max_metadata_len\x18\x01 \x01(\x04\x12\x11\n\tauthority\x18\x02 \x01(\t:*\xba\xc0\x96\xda\x01$\n\"github.com/cosmos/cosmos-sdk/x/govb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.module.v1.module_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MODULE._options = None
  _MODULE._serialized_options = b'\272\300\226\332\001$\n\"github.com/cosmos/cosmos-sdk/x/gov'
  _globals['_MODULE']._serialized_start=93
  _globals['_MODULE']._serialized_end=190
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/oracle/v1beta1/events.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"|\n\x16SetChainlinkPriceEvent\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12>\n\x06\x61nswer\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\"\x9d\x01\n\x11SetBandPriceEvent\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12=\n\x05price\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x14\n\x0cresolve_time\x18\x04 \x01(\x04\x12\x12\n\nrequest_id\x18\x05 \x01(\x04\"\xb5\x01\n\x14SetBandIBCPriceEvent\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0f\n\x07symbols\x18\x02 \x03(\t\x12>\n\x06prices\x18\x03 \x03(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x14\n\x0cresolve_time\x18\x04 \x01(\x04\x12\x12\n\nrequest_id\x18\x05 \x01(\x04\x12\x11\n\tclient_id\x18\x06 \x01(\x03\"?\n\x16\x45ventBandIBCAckSuccess\x12\x12\n\nack_result\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\x03\"<\n\x14\x45ventBandIBCAckError\x12\x11\n\tack_error\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\x03\"0\n\x1b\x45ventBandIBCResponseTimeout\x12\x11\n\tclient_id\x18\x01 \x01(\x03\"\x85\x01\n\x16SetPriceFeedPriceEvent\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\t\x12\r\n\x05quote\x18\x03 \x01(\t\x12=\n\x05price\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\x89\x01\n\x15SetProviderPriceEvent\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0f\n\x07relayer\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12=\n\x05price\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"y\n\x15SetCoinbasePriceEvent\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12=\n\x05price\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\"N\n\x12\x45ventSetPythPrices\x12\x38\n\x06prices\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.PythPriceStateBNZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types'
  _SETCHAINLINKPRICEEVENT.fields_by_name['answer']._options = None
  _SETCHAINLINKPRICEEVENT.fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SETBANDPRICEEVENT.fields_by_name['price']._options = None
  _SETBANDPRICEEVENT.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SETBANDIBCPRICEEVENT.fields_by_name['prices']._options = None
  _SETBANDIBCPRICEEVENT.fields_by_name['prices']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SETPRICEFEEDPRICEEVENT.fields_by_name['price']._options = None
  _SETPRICEFEEDPRICEEVENT.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SETPROVIDERPRICEEVENT.fields_by_name['price']._options = None
  _SETPROVIDERPRICEEVENT.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SETCOINBASEPRICEEVENT.fields_by_name['price']._options = None
  _SETCOINBASEPRICEEVENT.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _globals['_SETCHAINLINKPRICEEVENT']._serialized_start=160
  _globals['_SETCHAINLINKPRICEEVENT']._serialized_end=284
  _globals['_SETBANDPRICEEVENT']._serialized_start=287
  _globals['_SETBANDPRICEEVENT']._serialized_end=444
  _globals['_SETBANDIBCPRICEEVENT']._serialized_start=447
  _globals['_SETBANDIBCPRICEEVENT']._serialized_end=628
  _globals['_EVENTBANDIBCACKSUCCESS']._serialized_start=630
  _globals['_EVENTBANDIBCACKSUCCESS']._serialized_end=693
  _globals['_EVENTBANDIBCACKERROR']._serialized_start=695
  _globals['_EVENTBANDIBCACKERROR']._serialized_end=755
  _globals['_EVENTBANDIBCRESPONSETIMEOUT']._serialized_start=757
  _globals['_EVENTBANDIBCRESPONSETIMEOUT']._serialized_end=805
  _globals['_SETPRICEFEEDPRICEEVENT']._serialized_start=808
  _globals['_SETPRICEFEEDPRICEEVENT']._serialized_end=941
  _globals['_SETPROVIDERPRICEEVENT']._serialized_start=944
  _globals['_SETPROVIDERPRICEEVENT']._serialized_end=1081
  _globals['_SETCOINBASEPRICEEVENT']._serialized_start=1083
  _globals['_SETCOINBASEPRICEEVENT']._serialized_end=1204
  _globals['_EVENTSETPYTHPRICES']._serialized_start=1206
  _globals['_EVENTSETPYTHPRICES']._serialized_end=1284
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from exchange import injective_portfolio_rpc_pb2 as exchange_dot_injective__portfolio__rpc__pb2


class InjectivePortfolioRPCStub(object):
    """InjectivePortfolioRPC defines gRPC API of Exchange Portfolio provider.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AccountPortfolio = channel.unary_unary(
                '/injective_portfolio_rpc.InjectivePortfolioRPC/AccountPortfolio',
                request_serializer=exchange_dot_injective__portfolio__rpc__pb2.AccountPortfolioRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__portfolio__rpc__pb2.AccountPortfolioResponse.FromString,
                )
        self.StreamAccountPortfolio = channel.unary_stream(
                '/injective_portfolio_rpc.InjectivePortfolioRPC/StreamAccountPortfolio',
                request_serializer=exchange_dot_injective__portfolio__rpc__pb2.StreamAccountPortfolioRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__portfolio__rpc__pb2.StreamAccountPortfolioResponse.FromString,
                )


class InjectivePortfolioRPCServicer(object):
    """InjectivePortfolioRPC defines gRPC API of Exchange Portfolio provider.
    """

    def AccountPortfolio(self, request, context):
        """Provide the account's portfolio
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamAccountPortfolio(self, request, context):
        """Stream the account's portfolio
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectivePortfolioRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AccountPortfolio': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountPortfolio,
                    request_deserializer=exchange_dot_injective__portfolio__rpc__pb2.AccountPortfolioRequest.FromString,
                    response_serializer=exchange_dot_injective__portfolio__rpc__pb2.AccountPortfolioResponse.SerializeToString,
            ),
            'StreamAccountPortfolio': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamAccountPortfolio,
                    request_deserializer=exchange_dot_injective__portfolio__rpc__pb2.StreamAccountPortfolioRequest.FromString,
                    response_serializer=exchange_dot_injective__portfolio__rpc__pb2.StreamAccountPortfolioResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_portfolio_rpc.InjectivePortfolioRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InjectivePortfolioRPC(object):
    """InjectivePortfolioRPC defines gRPC API of Exchange Portfolio provider.
    """

    @staticmethod
    def AccountPortfolio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_portfolio_rpc.InjectivePortfolioRPC/AccountPortfolio',
            exchange_dot_injective__portfolio__rpc__pb2.AccountPortfolioRequest.SerializeToString,
            exchange_dot_injective__portfolio__rpc__pb2.AccountPortfolioResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamAccountPortfolio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_portfolio_rpc.InjectivePortfolioRPC/StreamAccountPortfolio',
            exchange_dot_injective__portfolio__rpc__pb2.StreamAccountPortfolioRequest.SerializeToString,
            exchange_dot_injective__portfolio__rpc__pb2.StreamAccountPortfolioResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/tx_response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/types/v1beta1/tx_response.proto\x12\x17injective.types.v1beta1\"8\n\x18TxResponseGenericMessage\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"U\n\x0eTxResponseData\x12\x43\n\x08messages\x18\x01 \x03(\x0b\x32\x31.injective.types.v1beta1.TxResponseGenericMessageB?Z=github.com/InjectiveLabs/injective-core/injective-chain/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.types.v1beta1.tx_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z=github.com/InjectiveLabs/injective-core/injective-chain/types'
  _globals['_TXRESPONSEGENERICMESSAGE']._serialized_start=70
  _globals['_TXRESPONSEGENERICMESSAGE']._serialized_end=126
  _globals['_TXRESPONSEDATA']._serialized_start=128
  _globals['_TXRESPONSEDATA']._serialized_end=213
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/client/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ibc/core/client/v1/genesis.proto\x12\x12ibc.core.client.v1\x1a\x1fibc/core/client/v1/client.proto\x1a\x14gogoproto/gogo.proto\"\xff\x03\n\x0cGenesisState\x12Z\n\x07\x63lients\x18\x01 \x03(\x0b\x32).ibc.core.client.v1.IdentifiedClientStateB\x1e\xc8\xde\x1f\x00\xaa\xdf\x1f\x16IdentifiedClientStates\x12\x80\x01\n\x11\x63lients_consensus\x18\x02 \x03(\x0b\x32).ibc.core.client.v1.ClientConsensusStatesB:\xc8\xde\x1f\x00\xf2\xde\x1f\x18yaml:\"clients_consensus\"\xaa\xdf\x1f\x16\x43lientsConsensusStates\x12h\n\x10\x63lients_metadata\x18\x03 \x03(\x0b\x32-.ibc.core.client.v1.IdentifiedGenesisMetadataB\x1f\xc8\xde\x1f\x00\xf2\xde\x1f\x17yaml:\"clients_metadata\"\x12\x30\n\x06params\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.ParamsB\x04\xc8\xde\x1f\x00\x12\x35\n\x10\x63reate_localhost\x18\x05 \x01(\x08\x42\x1b\xf2\xde\x1f\x17yaml:\"create_localhost\"\x12=\n\x14next_client_sequence\x18\x06 \x01(\x04\x42\x1f\xf2\xde\x1f\x1byaml:\"next_client_sequence\"\"3\n\x0fGenesisMetadata\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c:\x04\x88\xa0\x1f\x00\"\xa2\x01\n\x19IdentifiedGenesisMetadata\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\\\n\x0f\x63lient_metadata\x18\x02 \x03(\x0b\x32#.ibc.core.client.v1.GenesisMetadataB\x1e\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:\"client_metadata\"B:Z8github.com/cosmos/ibc-go/v7/modules/core/02-client/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/cosmos/ibc-go/v7/modules/core/02-client/types'
  _GENESISSTATE.fields_by_name['clients']._options = None
  _GENESISSTATE.fields_by_name['clients']._serialized_options = b'\310\336\037\000\252\337\037\026IdentifiedClientStates'
  _GENESISSTATE.fields_by_name['clients_consensus']._options = None
  _GENESISSTATE.fields_by_name['clients_consensus']._serialized_options = b'\310\336\037\000\362\336\037\030yaml:\"clients_consensus\"\252\337\037\026ClientsConsensusStates'
  _GENESISSTATE.fields_by_name['clients_metadata']._options = None
  _GENESISSTATE.fields_by_name['clients_metadata']._serialized_options = b'\310\336\037\000\362\336\037\027yaml:\"clients_metadata\"'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['create_localhost']._options = None
  _GENESISSTATE.fields_by_name['create_localhost']._serialized_options = b'\362\336\037\027yaml:\"create_localhost\"'
  _GENESISSTATE.fields_by_name['next_client_sequence']._options = None
  _GENESISSTATE.fields_by_name['next_client_sequence']._serialized_options = b'\362\336\037\033yaml:\"next_client_sequence\"'
  _GENESISMETADATA._options = None
  _GENESISMETADATA._serialized_options = b'\210\240\037\000'
  _IDENTIFIEDGENESISMETADATA.fields_by_name['client_id']._options = None
  _IDENTIFIEDGENESISMETADATA.fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _IDENTIFIEDGENESISMETADATA.fields_by_name['client_metadata']._options = None
  _IDENTIFIEDGENESISMETADATA.fields_by_name['client_metadata']._serialized_options = b'\310\336\037\000\362\336\037\026yaml:\"client_metadata\"'
  _globals['_GENESISSTATE']._serialized_start=112
  _globals['_GENESISSTATE']._serialized_end=623
  _globals['_GENESISMETADATA']._serialized_start=625
  _globals['_GENESISMETADATA']._serialized_end=676
  _globals['_IDENTIFIEDGENESISMETADATA']._serialized_start=679
  _globals['_IDENTIFIEDGENESISMETADATA']._serialized_end=841
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/p2p/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1atendermint/p2p/types.proto\x12\x0etendermint.p2p\x1a\x14gogoproto/gogo.proto\"B\n\nNetAddress\x12\x12\n\x02id\x18\x01 \x01(\tB\x06\xe2\xde\x1f\x02ID\x12\x12\n\x02ip\x18\x02 \x01(\tB\x06\xe2\xde\x1f\x02IP\x12\x0c\n\x04port\x18\x03 \x01(\r\"C\n\x0fProtocolVersion\x12\x14\n\x03p2p\x18\x01 \x01(\x04\x42\x07\xe2\xde\x1f\x03P2P\x12\r\n\x05\x62lock\x18\x02 \x01(\x04\x12\x0b\n\x03\x61pp\x18\x03 \x01(\x04\"\x93\x02\n\x0f\x44\x65\x66\x61ultNodeInfo\x12?\n\x10protocol_version\x18\x01 \x01(\x0b\x32\x1f.tendermint.p2p.ProtocolVersionB\x04\xc8\xde\x1f\x00\x12*\n\x0f\x64\x65\x66\x61ult_node_id\x18\x02 \x01(\tB\x11\xe2\xde\x1f\rDefaultNodeID\x12\x13\n\x0blisten_addr\x18\x03 \x01(\t\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x10\n\x08\x63hannels\x18\x06 \x01(\x0c\x12\x0f\n\x07moniker\x18\x07 \x01(\t\x12\x39\n\x05other\x18\x08 \x01(\x0b\x32$.tendermint.p2p.DefaultNodeInfoOtherB\x04\xc8\xde\x1f\x00\"M\n\x14\x44\x65\x66\x61ultNodeInfoOther\x12\x10\n\x08tx_index\x18\x01 \x01(\t\x12#\n\x0brpc_address\x18\x02 \x01(\tB\x0e\xe2\xde\x1f\nRPCAddressB3Z1github.com/cometbft/cometbft/proto/tendermint/p2pb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.p2p.types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/cometbft/cometbft/proto/tendermint/p2p'
  _NETADDRESS.fields_by_name['id']._options = None
  _NETADDRESS.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _NETADDRESS.fields_by_name['ip']._options = None
  _NETADDRESS.fields_by_name['ip']._serialized_options = b'\342\336\037\002IP'
  _PROTOCOLVERSION.fields_by_name['p2p']._options = None
  _PROTOCOLVERSION.fields_by_name['p2p']._serialized_options = b'\342\336\037\003P2P'
  _DEFAULTNODEINFO.fields_by_name['protocol_version']._options = None
  _DEFAULTNODEINFO.fields_by_name['protocol_version']._serialized_options = b'\310\336\037\000'
  _DEFAULTNODEINFO.fields_by_name['default_node_id']._options = None
  _DEFAULTNODEINFO.fields_by_name['default_node_id']._serialized_options = b'\342\336\037\rDefaultNodeID'
  _DEFAULTNODEINFO.fields_by_name['other']._options = None
  _DEFAULTNODEINFO.fields_by_name['other']._serialized_options = b'\310\336\037\000'
  _DEFAULTNODEINFOOTHER.fields_by_name['rpc_address']._options = None
  _DEFAULTNODEINFOOTHER.fields_by_name['rpc_address']._serialized_options = b'\342\336\037\nRPCAddress'
  _globals['_NETADDRESS']._serialized_start=68
  _globals['_NETADDRESS']._serialized_end=134
  _globals['_PROTOCOLVERSION']._serialized_start=136
  _globals['_PROTOCOLVERSION']._serialized_end=203
  _globals['_DEFAULTNODEINFO']._serialized_start=206
  _globals['_DEFAULTNODEINFO']._serialized_end=481
  _globals['_DEFAULTNODEINFOOTHER']._serialized_start=483
  _globals['_DEFAULTNODEINFOOTHER']._serialized_end=560
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/nft/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.nft.v1beta1 import nft_pb2 as cosmos_dot_nft_dot_v1beta1_dot_nft__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/nft/v1beta1/genesis.proto\x12\x12\x63osmos.nft.v1beta1\x1a\x1c\x63osmos/nft/v1beta1/nft.proto\"f\n\x0cGenesisState\x12*\n\x07\x63lasses\x18\x01 \x03(\x0b\x32\x19.cosmos.nft.v1beta1.Class\x12*\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x19.cosmos.nft.v1beta1.Entry\"=\n\x05\x45ntry\x12\r\n\x05owner\x18\x01 \x01(\t\x12%\n\x04nfts\x18\x02 \x03(\x0b\x32\x17.cosmos.nft.v1beta1.NFTB$Z\"github.com/cosmos/cosmos-sdk/x/nftb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.nft.v1beta1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/cosmos/cosmos-sdk/x/nft'
  _globals['_GENESISSTATE']._serialized_start=86
  _globals['_GENESISSTATE']._serialized_end=188
  _globals['_ENTRY']._serialized_start=190
  _globals['_ENTRY']._serialized_end=251
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&injective/exchange/v1beta1/authz.proto\x12\x1ainjective.exchange.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\"Y\n\x19\x43reateSpotLimitOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xca\xb4-\rAuthorization\"Z\n\x1a\x43reateSpotMarketOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xca\xb4-\rAuthorization\"_\n\x1f\x42\x61tchCreateSpotLimitOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xca\xb4-\rAuthorization\"T\n\x14\x43\x61ncelSpotOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xca\xb4-\rAuthorization\"Z\n\x1a\x42\x61tchCancelSpotOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xca\xb4-\rAuthorization\"_\n\x1f\x43reateDerivativeLimitOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xca\xb4-\rAuthorization\"`\n CreateDerivativeMarketOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xca\xb4-\rAuthorization\"e\n%BatchCreateDerivativeLimitOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xca\xb4-\rAuthorization\"Z\n\x1a\x43\x61ncelDerivativeOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xca\xb4-\rAuthorization\"`\n BatchCancelDerivativeOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xca\xb4-\rAuthorization\"t\n\x16\x42\x61tchUpdateOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x14\n\x0cspot_markets\x18\x02 \x03(\t\x12\x1a\n\x12\x64\x65rivative_markets\x18\x03 \x03(\t:\x11\xca\xb4-\rAuthorizationBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v1beta1.authz_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types'
  _CREATESPOTLIMITORDERAUTHZ._options = None
  _CREATESPOTLIMITORDERAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _CREATESPOTMARKETORDERAUTHZ._options = None
  _CREATESPOTMARKETORDERAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _BATCHCREATESPOTLIMITORDERSAUTHZ._options = None
  _BATCHCREATESPOTLIMITORDERSAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _CANCELSPOTORDERAUTHZ._options = None
  _CANCELSPOTORDERAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _BATCHCANCELSPOTORDERSAUTHZ._options = None
  _BATCHCANCELSPOTORDERSAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _CREATEDERIVATIVELIMITORDERAUTHZ._options = None
  _CREATEDERIVATIVELIMITORDERAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _CREATEDERIVATIVEMARKETORDERAUTHZ._options = None
  _CREATEDERIVATIVEMARKETORDERAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _BATCHCREATEDERIVATIVELIMITORDERSAUTHZ._options = None
  _BATCHCREATEDERIVATIVELIMITORDERSAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _CANCELDERIVATIVEORDERAUTHZ._options = None
  _CANCELDERIVATIVEORDERAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _BATCHCANCELDERIVATIVEORDERSAUTHZ._options = None
  _BATCHCANCELDERIVATIVEORDERSAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _BATCHUPDATEORDERSAUTHZ._options = None
  _BATCHUPDATEORDERSAUTHZ._serialized_options = b'\312\264-\rAuthorization'
  _globals['_CREATESPOTLIMITORDERAUTHZ']._serialized_start=97
  _globals['_CREATESPOTLIMITORDERAUTHZ']._serialized_end=186
  _globals['_CREATESPOTMARKETORDERAUTHZ']._serialized_start=188
  _globals['_CREATESPOTMARKETORDERAUTHZ']._serialized_end=278
  _globals['_BATCHCREATESPOTLIMITORDERSAUTHZ']._serialized_start=280
  _globals['_BATCHCREATESPOTLIMITORDERSAUTHZ']._serialized_end=375
  _globals['_CANCELSPOTORDERAUTHZ']._serialized_start=377
  _globals['_CANCELSPOTORDERAUTHZ']._serialized_end=461
  _globals['_BATCHCANCELSPOTORDERSAUTHZ']._serialized_start=463
  _globals['_BATCHCANCELSPOTORDERSAUTHZ']._serialized_end=553
  _globals['_CREATEDERIVATIVELIMITORDERAUTHZ']._serialized_start=555
  _globals['_CREATEDERIVATIVELIMITORDERAUTHZ']._serialized_end=650
  _globals['_CREATEDERIVATIVEMARKETORDERAUTHZ']._serialized_start=652
  _globals['_CREATEDERIVATIVEMARKETORDERAUTHZ']._serialized_end=748
  _globals['_BATCHCREATEDERIVATIVELIMITORDERSAUTHZ']._serialized_start=750
  _globals['_BATCHCREATEDERIVATIVELIMITORDERSAUTHZ']._serialized_end=851
  _globals['_CANCELDERIVATIVEORDERAUTHZ']._serialized_start=853
  _globals['_CANCELDERIVATIVEORDERAUTHZ']._serialized_end=943
  _globals['_BATCHCANCELDERIVATIVEORDERSAUTHZ']._serialized_start=945
  _globals['_BATCHCANCELDERIVATIVEORDERSAUTHZ']._serialized_end=1041
  _globals['_BATCHUPDATEORDERSAUTHZ']._serialized_start=1043
  _globals['_BATCHUPDATEORDERSAUTHZ']._serialized_end=1159
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/autocli/v1/options.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/autocli/v1/options.proto\x12\x11\x63osmos.autocli.v1\"\x84\x01\n\rModuleOptions\x12\x37\n\x02tx\x18\x01 \x01(\x0b\x32+.cosmos.autocli.v1.ServiceCommandDescriptor\x12:\n\x05query\x18\x02 \x01(\x0b\x32+.cosmos.autocli.v1.ServiceCommandDescriptor\"\xa3\x02\n\x18ServiceCommandDescriptor\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x41\n\x13rpc_command_options\x18\x02 \x03(\x0b\x32$.cosmos.autocli.v1.RpcCommandOptions\x12R\n\x0csub_commands\x18\x03 \x03(\x0b\x32<.cosmos.autocli.v1.ServiceCommandDescriptor.SubCommandsEntry\x1a_\n\x10SubCommandsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.cosmos.autocli.v1.ServiceCommandDescriptor:\x02\x38\x01\"\x9f\x03\n\x11RpcCommandOptions\x12\x12\n\nrpc_method\x18\x01 \x01(\t\x12\x0b\n\x03use\x18\x02 \x01(\t\x12\x0c\n\x04long\x18\x03 \x01(\t\x12\r\n\x05short\x18\x04 \x01(\t\x12\x0f\n\x07\x65xample\x18\x05 \x01(\t\x12\r\n\x05\x61lias\x18\x06 \x03(\t\x12\x13\n\x0bsuggest_for\x18\x07 \x03(\t\x12\x12\n\ndeprecated\x18\x08 \x01(\t\x12\x0f\n\x07version\x18\t \x01(\t\x12K\n\x0c\x66lag_options\x18\n \x03(\x0b\x32\x35.cosmos.autocli.v1.RpcCommandOptions.FlagOptionsEntry\x12\x43\n\x0fpositional_args\x18\x0b \x03(\x0b\x32*.cosmos.autocli.v1.PositionalArgDescriptor\x12\x0c\n\x04skip\x18\x0c \x01(\x08\x1aR\n\x10\x46lagOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.cosmos.autocli.v1.FlagOptions:\x02\x38\x01\"\xb4\x01\n\x0b\x46lagOptions\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tshorthand\x18\x02 \x01(\t\x12\r\n\x05usage\x18\x03 \x01(\t\x12\x15\n\rdefault_value\x18\x04 \x01(\t\x12\x1c\n\x14no_opt_default_value\x18\x05 \x01(\t\x12\x12\n\ndeprecated\x18\x06 \x01(\t\x12\x1c\n\x14shorthand_deprecated\x18\x07 \x01(\t\x12\x0e\n\x06hidden\x18\x08 \x01(\x08\"?\n\x17PositionalArgDescriptor\x12\x13\n\x0bproto_field\x18\x01 \x01(\t\x12\x0f\n\x07varargs\x18\x02 \x01(\x08\x42+Z)cosmossdk.io/api/cosmos/base/cli/v1;cliv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.autocli.v1.options_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)cosmossdk.io/api/cosmos/base/cli/v1;cliv1'
  _SERVICECOMMANDDESCRIPTOR_SUBCOMMANDSENTRY._options = None
  _SERVICECOMMANDDESCRIPTOR_SUBCOMMANDSENTRY._serialized_options = b'8\001'
  _RPCCOMMANDOPTIONS_FLAGOPTIONSENTRY._options = None
  _RPCCOMMANDOPTIONS_FLAGOPTIONSENTRY._serialized_options = b'8\001'
  _globals['_MODULEOPTIONS']._serialized_start=55
  _globals['_MODULEOPTIONS']._serialized_end=187
  _globals['_SERVICECOMMANDDESCRIPTOR']._serialized_start=190
  _globals['_SERVICECOMMANDDESCRIPTOR']._serialized_end=481
  _globals['_SERVICECOMMANDDESCRIPTOR_SUBCOMMANDSENTRY']._serialized_start=386
  _globals['_SERVICECOMMANDDESCRIPTOR_SUBCOMMANDSENTRY']._serialized_end=481
  _globals['_RPCCOMMANDOPTIONS']._serialized_start=484
  _globals['_RPCCOMMANDOPTIONS']._serialized_end=899
  _globals['_RPCCOMMANDOPTIONS_FLAGOPTIONSENTRY']._serialized_start=817
  _globals['_RPCCOMMANDOPTIONS_FLAGOPTIONSENTRY']._serialized_end=899
  _globals['_FLAGOPTIONS']._serialized_start=902
  _globals['_FLAGOPTIONS']._serialized_end=1082
  _globals['_POSITIONALARGDESCRIPTOR']._serialized_start=1084
  _globals['_POSITIONALARGDESCRIPTOR']._serialized_end=1147
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/app/v1alpha1/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/app/v1alpha1/config.proto\x12\x13\x63osmos.app.v1alpha1\x1a\x19google/protobuf/any.proto\"y\n\x06\x43onfig\x12\x32\n\x07modules\x18\x01 \x03(\x0b\x32!.cosmos.app.v1alpha1.ModuleConfig\x12;\n\x0fgolang_bindings\x18\x02 \x03(\x0b\x32\".cosmos.app.v1alpha1.GolangBinding\"\x7f\n\x0cModuleConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12;\n\x0fgolang_bindings\x18\x03 \x03(\x0b\x32\".cosmos.app.v1alpha1.GolangBinding\"?\n\rGolangBinding\x12\x16\n\x0einterface_type\x18\x01 \x01(\t\x12\x16\n\x0eimplementation\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.app.v1alpha1.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONFIG']._serialized_start=84
  _globals['_CONFIG']._serialized_end=205
  _globals['_MODULECONFIG']._serialized_start=207
  _globals['_MODULECONFIG']._serialized_end=334
  _globals['_GOLANGBINDING']._serialized_start=336
  _globals['_GOLANGBINDING']._serialized_end=399
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from decimal import Decimal


@dataclass(eq=True, frozen=True)
class Token:
    name: str
    symbol: str
    denom: str
    address: str
    decimals: int
    logo: str
    updated: int

    def chain_formatted_value(self, human_readable_value: Decimal) -> Decimal:
        return human_readable_value * Decimal(f"1e{self.decimals}")
